# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import enum

import winrt.system
from winrt import _winrt_windows_applicationmodel_socialinfo

__all__ = [
    "SocialFeedItemStyle",
    "SocialFeedKind",
    "SocialFeedUpdateMode",
    "SocialItemBadgeStyle",
    "SocialFeedChildItem",
    "SocialFeedContent",
    "SocialFeedItem",
    "SocialFeedSharedItem",
    "SocialItemThumbnail",
    "SocialUserInfo",
]

class SocialFeedItemStyle(enum.IntEnum):
    DEFAULT = 0
    PHOTO = 1

class SocialFeedKind(enum.IntEnum):
    HOME_FEED = 0
    CONTACT_FEED = 1
    DASHBOARD = 2

class SocialFeedUpdateMode(enum.IntEnum):
    APPEND = 0
    REPLACE = 1

class SocialItemBadgeStyle(enum.IntEnum):
    HIDDEN = 0
    VISIBLE = 1
    VISIBLE_WITH_COUNT = 2

SocialFeedChildItem = _winrt_windows_applicationmodel_socialinfo.SocialFeedChildItem
SocialFeedContent = _winrt_windows_applicationmodel_socialinfo.SocialFeedContent
SocialFeedItem = _winrt_windows_applicationmodel_socialinfo.SocialFeedItem
SocialFeedSharedItem = _winrt_windows_applicationmodel_socialinfo.SocialFeedSharedItem
SocialItemThumbnail = _winrt_windows_applicationmodel_socialinfo.SocialItemThumbnail
SocialUserInfo = _winrt_windows_applicationmodel_socialinfo.SocialUserInfo
